Finds regions of adjacent reaches.
adjacentreaches(x,...)Numerical vector of the same length as the number of reaches in the river network with unique numbering corresponding to regions of adjacent reaches (under the condition specified by crit.reach and thresh.length). The segment labelled 0 corresponds to reaches that do not fulfill the criteria. The other regions are labelled with 1, 2, 3, ...
Object of class "rivernet" e.g. read by the function rivernet.read.
.
rivernet.read, mean.rivernet, upstreamconnectivity.rivernet,
utility.