Gets indices of reaches that are closest to given locations
getreachind(net,x,y,...)A data frame with the indices in the first and the distances in the second column.
Object of class "rivernet" e.g. read by the function rivernet.read.
Numerical vector of x coordinates of sites to be analyzed (needs to be of the same length as argument y).
Numerical vector of y coordinates of sites to be analyzed (needs to be of the same length as argument x).
.
rivernet.read, getnodeind.rivernet, upstreamconnectivity.rivernet, adjacentreaches.rivernet,
utility.