Learn R Programming

rivernet (version 1.2.3)

mean.rivernet: Calculates the length and stream order - weighted average of a given reach property

Description

Calculates the length and stream order - weighted average of a given reach property.

Usage

# S3 method for rivernet
mean(x,y=NA,na.rm=FALSE,...)

Value

A scalar representing the weighted mean.

Arguments

x

Object of class "rivernet" e.g. read by the function rivernet.read.

y

Numerical vector of properties of reaches to be averaged. If no values are provided, the function returns the average length of the reaches.

na.rm

Indication whether NAs should be removed.

...

.

See Also

rivernet.read, upstreamconnectivity.rivernet, adjacentreaches.rivernet,
utility.